 
//video gen and sound
//D.5 is sync:1000 ohm + diode to 75 ohm resistor
//D.6 is video:330 ohm + diode to 75 ohm resistor  
//B.3 is sound  and should have a 10k resistor to gnd

#pragma regalloc-    //I allocate the registers myself
#pragma optsize-     //optimize for speed
                    
#include <Mega32.h>   
#include <stdio.h>
#include <stdlib.h> 
#include <math.h> 
#include <delay.h>   
#include "flash.h" 
#include "combo.h"

//cycles = 63.625 * 16 Note NTSC is 63.55 
//but this line duration makes each frame exactly 1/60 sec
//which is nice for keeping a realtime clock 
#define lineTime 1018
 
#define begin {
#define end   }
#define ScreenTop 30
#define ScreenBot 230
#define wordMatrixLength 20
#define maxWordLength 12


enum years {prefrosh=1,frosh,soph,junior,senior,trans,grad,job};
enum level {Dir=1, Init, Game, Check, TimesUp, ShowCredits, Ready};
enum buttons {upButton=1, downButton, leftButton, rightButton, startButton, AButton, BButton, CButton, upRightButton, downLeftButton};
enum song {none=1,alma,davy,NCFS,MYOC,bee,pomp,McD}; 

//NOTE that v1 to v8 and i must be in registers!  
register char v1 @4; 
register char v2 @5;
register char v3 @6;
register char v4 @7;
register char v5 @8;
register char v6 @9;
register char v7 @10;
register char v8 @11; 
register int i @12;

#pragma regalloc+ 

char syncON, syncOFF; 
int LineCount;
int timer;
eeprom int lastSeed=0;
int seed; 

//animation
char x, y, s, vx, vy, temp;

char screen[1600], time, timerString[10], creditsLabel[8]="CREDITS", creditsString[4]; 
char screenTitle[17], drawingFrame, blanks[11]="          ", mediumBlanks[21]="                    ", 
	longBlanks[31]="                              ", timesUpLabel[9]="TIMES UP", startLabel[24]="PRESS START TO CONTINUE",
	correctLabel[8]="CORRECT", incorrectLabel[10]="INCORRECT";     

char screenString[31],degreeString1[10],degreeString2[12];
unsigned char prevController, controller, credits, timesUp, gameTime, stopTime; 

flash char wordMatrix[wordMatrixLength][maxWordLength] = {"CALCULUS","GEOMETRY","COSINE","TANGENT","FUNCTION",
							  "INFINITE","FOURIER","THEOREM","INTEGRATE","DERIVATIVE",
							  "TAYLOR","CARTESIAN","LAGRANGE","FLUX","VECTOR",
							  "ASYMPTOTE","BINOMIAL","MATRIX","MAGNITUDE","SCALAR"};

char wordNumber, showWord, wordsUsedIndex, wordGuessIndex, lastScrambleIndex, prevWordCursorX, wordCursorX, wordCursorY, wordLength, 
	prevChalkCursorX, chalkCursorX, chalkCursorY, WSCount;
char wordSelected[maxWordLength], wordGuessed[maxWordLength], wordScrambled[maxWordLength], wordsUsed[10], lastScramblePos[maxWordLength];

char ThumbelinaX, ThumbelinaY, studentX, studentY, canMove, totalCredits;      
 
char holdCap, holdRes, holdInd, capTime, indTime, resTime, capY, indY, resY; 
unsigned int DDRcount,count;

char yearState, levelState, displayCount; 

unsigned char pushState, pushFlag, button, holdCount, holdCountReset;
enum pushStates {noPush=1, maybePush, push, maybeNoPush}; 

char songState;


// Used for music
unsigned char noteIndex, noteLength, songLength, songNoteLength, noteVal, noteReset;

// Function prototypes
void initialize(void);   
void enroll(void); 
void graduate(void);               			

	
//==================================
//This is the sync generator and raster generator. It MUST be entered from 
//sleep mode to get accurate timing of the sync pulses
//==================================
#pragma warn-
interrupt [TIM1_COMPA] void t1_cmpA(void)  
begin 
  //start the Horizontal sync pulse    
  PORTD = syncON;     
  //update the curent scanline number
  LineCount ++ ;   
  //begin inverted (Vertical) synch after line 247
  if (LineCount==248)
  begin 
    syncON = 0b00100000;
    syncOFF = 0;
  end
  //back to regular sync after line 250
  if (LineCount==251)	
  begin
    syncON = 0;
    syncOFF = 0b00100000;
  end  
  //start new frame after line 262
  if (LineCount==263) 
  begin
     LineCount = 1;
  end  
  
  delay_us(2); //adjust to make 5 us pulses
  //end sync pulse
  PORTD = syncOFF;   
  
  if (LineCount<ScreenBot && LineCount>=ScreenTop) 
    begin 
       
       //compute byte index for beginning of the next line
       //left-shift 4 would be individual lines
       // <<3 means line-double the pixels 
       //The 0xfff8 truncates the odd line bit
       //i=(LineCount-ScreenTop)<<3 & 0xfff8; //
       
       #asm
       push r16
       lds   r12, _LineCount
       lds   r13, _Linecount+1
       ldi   r16, 30
       sub  r12, r16 
       ldi  r16,0
       sbc  r13, r16 
       lsl  r12
       rol  r13
       lsl  r12
       rol  r13
       lsl  r12    
       rol  r13
       mov  r16,r12
       andi r16,0xf0
       mov  r12,r16
       pop r16 
       #endasm
        
       //load 16 registers with screen info
       #asm
       push r14
       push r15
       push r16
       push r17
       push r18 
       push r19 
       push r26
       push r27
       
       ldi  r26,low(_screen)   ;base address of screen
       ldi  r27,high(_screen)   
       add  r26,r12            ;offset into screen (add i)
       adc  r27,r13
       ld   r4,x+   	       ;load 16 registers and inc pointer
       ld   r5,x+
       ld   r6,x+  
       ld   r7,x+
       ld   r8,x+ 
       ld   r9,x+
       ld   r10,x+  
       ld   r11,x+
       ld   r12,x+ 
       ld   r13,x+
       ld   r14,x+  
       ld   r15,x+
       ld   r16,x+   
       ld   r17,x+  
       ld   r18,x+
       ld   r19,x 
       
       pop  r27
       pop  r26
       #endasm  

       delay_us(4);  //adjust to center image on screen
       
       //blast 16 bytes to the screen   
       #asm
       ;but first a macro to make the code shorter  
       ;the macro takes a register number as a parameter
       ;and dumps its bits serially to portD.6   
       ;the nop can be eliminated to make the display narrower
       .macro videobits ;regnum
        BST  @0,7
	IN   R30,0x12
	BLD  R30,6
	nop
	OUT  0x12,R30  
	
	BST  @0,6
	IN   R30,0x12
	BLD  R30,6
	nop
	OUT  0x12,R30 
	
	BST  @0,5
	IN   R30,0x12
	BLD  R30,6 
	nop
	OUT  0x12,R30 
	
	BST  @0,4
	IN   R30,0x12
	BLD  R30,6
	nop
	OUT  0x12,R30 
	
	BST  @0,3
	IN   R30,0x12
	BLD  R30,6
	nop
	OUT  0x12,R30 
	
	BST  @0,2
	IN   R30,0x12
	BLD  R30,6
	nop
	OUT  0x12,R30 
	
	BST  @0,1
	IN   R30,0x12
	BLD  R30,6 
	nop
	OUT  0x12,R30 
	
	BST  @0,0
	IN   R30,0x12
	BLD  R30,6
	nop
	OUT  0x12,R30 
       .endm     
        
	videobits r4 ;video line -- byte 1
        videobits r5 ;byte 2  
        videobits r6 ;byte 3
        videobits r7 ;byte 4
        videobits r8 ;byte 5
        videobits r9 ;byte 6
        videobits r10 ;byte 7
        videobits r11 ;byte 8 
        videobits r12 ;byte 9
        videobits r13 ;byte 10  
        videobits r14 ;byte 11
        videobits r15 ;byte 12
        videobits r16 ;byte 13
        videobits r17 ;byte 14
        videobits r18 ;byte 15
        videobits r19 ;byte 16
	clt   ;clear video after the last pixel on the line
	IN   R30,0x12
	BLD  R30,6
	OUT  0x12,R30
								
       pop r19
       pop r18
       pop r17 
       pop r16  
       pop r15
       pop r14
       #endasm
              
    end         
end  
#pragma warn+


//==================================
// set up the ports and timers
//==================================
void initialize(void)
begin 
  //init timer 1 to generate sync
  OCR1A = lineTime; 	//One NTSC line
  TCCR1B = 0b00001001; 	//full speed; clear-on-match
  TCCR1A = 0x00;	//turn off pwm and oc lines
  TIMSK = 0x10;		//enable interrupt T1 cmp 
  
  //init ports
  DDRD = 0xf0;		//video out and switches
  //D.5 is sync:1000 ohm + diode to 75 ohm resistor
  //D.6 is video:330 ohm + diode to 75 ohm resistor
  DDRA = 0x00;
  PORTA = 0xff;
  DDRB = 0xff;
  PORTB = 0xff;
  DDRC = 0x01;
  PORTC = 0xfe;
  
  //initialize synch constants 
  LineCount = 1;
  syncON = 0b00000000;
  syncOFF = 0b00100000;
  
  //side lines 
  #define width 126
  video_line(0,0,0,99,1);
  video_line(width,0,width,99,1);
  
  //top line & bottom lines
  video_line(0,0,width,0,1);
  video_line(0,99,width,99,1);
  video_line(0,11,width,11,1);
  video_line(0,89,width,89,1);
  
  video_line(6,88,6,45,1); //left side of tower
  video_line(29,88,29,45,1); //right side of tower
  video_line(6,44,18,21,1); //left side of roof
  video_line(18,21,29,44,1); //right side of roof
  video_line(18,22,18,88,1); //center line of tower 
  video_line(6,45,18,36,1); //underside of left roof
  video_line(18,36,29,45,1); //underside of right roof  
  
   //left window
  video_line(9,50,9,59,1);
  video_line(15,47,15,56,1);
  video_line(9,50,15,47,1);
  video_line(9,59,15,56,1); 
  
  //right window
  video_line(21,47,21,56,1);
  video_line(26,50,26,59,1);
  video_line(21,47,26,50,1);
  video_line(21,56,26,59,1);
  
  //left clock
  video_line(9,70,9,66,1);
  /*video_pt(9,70,1);//left side
  video_pt(9,69,1);
  video_pt(9,68,1);
  video_pt(9,67,1);
  video_pt(9,66,1);*/
  video_line(15,70,15,66,1);
  /*video_pt(15,70,1);//right side
  video_pt(15,69,1);
  video_pt(15,68,1);
  video_pt(15,67,1);
  video_pt(15,66,1);*/
  video_pt(10,65,1);//"corners"
  video_pt(10,71,1);
  video_pt(14,65,1);
  video_pt(14,71,1);
  video_line(11,64,13,64,1);
  /*video_pt(11,64,1);//top
  video_pt(12,64,1);
  video_pt(13,64,1);*/
  video_line(11,72,13,72,1);
  /*video_pt(11,72,1);//bottom
  video_pt(12,72,1);
  video_pt(13,72,1);*/
  
  //right clock
  video_line(21,70,21,66,1);
  /*video_pt(21,70,1);//left side
  video_pt(21,69,1);
  video_pt(21,68,1);
  video_pt(21,67,1);
  video_pt(21,66,1);*/
  video_line(26,70,26,66,1);
  /*video_pt(26,70,1);//right side
  video_pt(26,69,1);
  video_pt(26,68,1);
  video_pt(26,67,1);
  video_pt(26,66,1);*/
  video_pt(22,65,1);//"corners"
  video_pt(22,71,1);
  video_pt(25,65,1);
  video_pt(25,71,1);
  video_line(23,64,24,64,1);
  /*video_pt(23,64,1);//top
  video_pt(24,64,1);*/
  video_line(23,72,24,72,1);
  /*video_pt(23,72,1);//bottom
  video_pt(24,72,1);*/
   
  sprintf(screenString,"WELCOME TO");
  video_putsmalls(48,25,screenString);
  
  sprintf(screenString,"Cornell");
  video_puts(48,35, screenString);
  
  sprintf(screenString,"100 CREDITS TO GRADUATE");
  video_putsmalls(32,60,screenString);
  
  sprintf(screenString,"PRESS START TO ENROLL");
  video_putsmalls(32,80,screenString);

  //init musical scale
  noteIndex = 1;
  noteLength = 0;
  //use OC0 (pin B.3) for music  
  DDRB.3 = 1;    
  
  pushState = noPush;
  drawingFrame = 0; 
  seed = lastSeed; //ensures that the random number to pick a random word for the scramble is different everytime
  
  yearState = prefrosh; //start the state machine at the clock tower start screen
  levelState = Dir;
  songState = alma;
  displayCount = 0;
  holdCountReset = 30; //controls the delay for reading the controller (this waits 30ms for each debouncer cycle)
  
  credits = 40;
  
  //enable sleep mode
  MCUCR = 0b10000000;
  #asm ("sei");
end


//==================================
//erases the start screen when the start button is pressed
//and initializes for the understand your math TA level
//==================================
void enroll(void)
begin
	if (button==startButton)
	begin
		switch(drawingFrame)
		begin
			case(0):
			begin   
				  //PORTB=0x00;
				  video_line(6,88,6,45,0); //left side of tower
				  video_line(29,88,29,45,0); //right side of tower
				  video_line(6,44,18,21,0); //left side of roof
				  video_line(18,21,29,44,0); //right side of roof
				  video_line(18,22,18,88,0); //center line of tower
				  video_line(6,45,18,36,0); //underside of left roof
  				  video_line(18,36,29,45,0); //underside of right roof 
				  
				  //left window
				  video_line(9,50,9,59,0);
				  video_line(15,47,15,56,0);
				  video_line(9,50,15,47,0);
				  video_line(9,59,15,56,0); 
				  
				  //right window
				  video_line(21,47,21,56,0);
				  video_line(26,50,26,59,0);
				  video_line(21,47,26,50,0);
				  video_line(21,56,26,59,0);
				  
				  //left clock
                      video_line(9,70,9,66,0);
                      /*video_pt(9,70,0);//left side
                      video_pt(9,69,0);
                      video_pt(9,68,0);
                      video_pt(9,67,0);
                      video_pt(9,66,0);*/
                      video_line(15,70,15,66,0);
                      /*video_pt(15,70,0);//right side
                      video_pt(15,69,0);
                      video_pt(15,68,0);
                      video_pt(15,67,0);
                      video_pt(15,66,0);*/
                      video_pt(10,65,0);//"corners"
                      video_pt(10,71,0);
                      video_pt(14,65,0);
                      video_pt(14,71,0);
                      video_line(11,64,13,64,0);
                      /*video_pt(11,64,0);//top
                      video_pt(12,64,0);
                      video_pt(13,64,0);*/
                      video_line(11,72,13,72,0);
                      /*video_pt(11,72,0);//bottom
                      video_pt(12,72,0);
                      video_pt(13,72,0);*/
                      
                      //right clock
                      video_line(21,70,21,66,0);
                      /*video_pt(21,70,0);//left side
                      video_pt(21,69,0);
                      video_pt(21,68,0);
                      video_pt(21,67,0);
                      video_pt(21,66,0);*/
                      video_line(26,70,26,66,0);
                      /*video_pt(26,70,0);//right side
                      video_pt(26,69,0);
                      video_pt(26,68,0);
                      video_pt(26,67,0);
                      video_pt(26,66,0);*/
                      video_pt(22,65,0);//"corners"
                      video_pt(22,71,0);
                      video_pt(25,65,0);
                      video_pt(25,71,0);
                      video_line(23,64,24,64,0);
                      /*video_pt(23,64,0);//top
                      video_pt(24,64,0);*/
                      video_line(23,72,24,72,0);
                      /*video_pt(23,72,0);//bottom
                      video_pt(24,72,0);*/
				  
			drawingFrame=1;       						
			break;
			end//case0
			case(1):
			begin
                      video_putsmalls(48,25,blanks);

                      video_putsmalls(4,60,longBlanks);

                      video_putsmalls(4,80,longBlanks);
                      
                      //show credits
                      credits = 0;
                      sprintf(creditsString,"%03d",credits);
                      video_putsmalls(4,92,creditsString);
                      video_putsmalls(20,92,creditsLabel);
  
				drawingFrame=2;
				songState=none;
				noteIndex=1;
				break;
			end
			case(2):
			begin
				video_puts(48,35, blanks);
				drawingFrame=0;
				yearState=frosh;
				button=0;
				credits = 0;
				break;
			end
		end//switch 
	end//if start pushed
end


//==================================
//when you dont have enough credits the state machine will call this function
//to allow you to pick new plans
//==================================
void transfer(void)
begin
   	switch(drawingFrame)
   	begin
   	   	case(0):
   	   	begin
   	   	   	sprintf(screenString,"UNFORTUNATELY YOU DO NOT HAVE");
   	   	   	video_putsmalls(4,15,screenString);
   	   	   	
   	   	   	sprintf(screenString,"ENOUGH CREDITS TO GRADUATE");
   	   	   	video_putsmalls(4,22,screenString);
   	   	   	   	   	   	   	   	   	
   	   	   	drawingFrame=1;
   	   	   	break;
   	   	end 
   	   	case(1):
   	   	begin
   	   		sprintf(screenString,"FROM THE ENGINEERING SCHOOL");
   	   	   	video_putsmalls(4,29,screenString);
   	   	   	
   	   	   	
   	   	   	sprintf(screenString,"WOUD YOU LIKE TO");
   	   	   	video_putsmalls(4,40,screenString);
   	   	   	
   	   	   	drawingFrame=2;
   	   	   	break;
   	   	end
   	   	case(2):
   	   	begin 
   	   		sprintf(screenString,"BUTTON A: TRANSFER TO HOTEL");
   	   	   	video_putsmalls(4,47,screenString);
   	   	   		
   	   	   	sprintf(screenString,"BUTTON B: LOOK FOR JOB ANYWAY");
   	   	    	video_putsmalls(4,54,screenString);
   	   	   	
   	   	   	drawingFrame=3;
   	   	   	break;
   	   	end
   	   	case(3):
   	   	begin 
   	   		switch(button)
   	   		begin
   	   		   	case(AButton): //will transfer you to the hotel school
   	   		   	begin
   	   		   		sprintf(screenString,"SCHOOL OF HOTEL ADMIN");
   	   		   		levelState=grad;
   	   		   		songState=pomp;
   	   		   		noteIndex=1;
   	   		   		drawingFrame=4;
   	   		   		video_line(1,11,width-1,11,0); 
   	   		   		video_line(1,89,width-1,89,0);
   	   		   		break;
   	   		   	end
   	   		   	case(BButton)://gives you a job at mcdonalds
   	   		   	begin
   	   		   		sprintf(screenString,"IM LOVIN IT"); //copyrighted by McDonald's
   	   		   		levelState=job;
   	   		   		songState=McD;
   	   		   		noteIndex=1;
   	   		   		drawingFrame=4;
   	   		   		video_line(1,11,width-1,11,0); 
   	   		   		break;
   	   		   	end
   	   		end
   	   		button=0;
   	   	   	break;
   	   	end
   	   	case(4):
   	   	begin
   	   	   	video_putsmalls(4,15,longBlanks); //erases text
   	   	   	video_putsmalls(4,22,longBlanks);
   	   	   	video_putsmalls(4,29,longBlanks); 	   	   	   	   	   	   	   	   	
   	   	   	drawingFrame=5;
   	   	   	break;
   	   	end 
   	   	case(5):
   	   	begin
   	   	   	video_putsmalls(4,40,longBlanks); //erases text
   	   	   	video_putsmalls(4,47,longBlanks);
   	   	    	video_putsmalls(4,54,longBlanks);
   	   	   	drawingFrame=0;
   	   	   	yearState=levelState;
   	   	   	break;
   	   	end

   	end
end

//==================================
//draws your degree when you have accrued enough credits to graduate
//also decides which degree you will receive based on the number of credits you have earned:
//   BS between 100 - 108 credits
//   with Honors between 109-129 credits
//   Masters greater than 129 credits
//==================================
void graduate(void)
begin
	switch(drawingFrame)
	begin
		case(0):
		begin      //Bachelors
                	sprintf(degreeString1,"BACHELORS");
                	//Honors 109-129
                	if (credits >=109 && credits <130)
                	begin
                	       sprintf(degreeString2,"WITH HONORS");
                	end
                	//Masters 130
                	else if (credits >=130)
                	begin
                	     	sprintf(degreeString2,"AND MASTERS");
                	end
                	else sprintf(degreeString2,""); 
                	
                	video_line(1,11,125,11,0);//erase game lines
          		video_line(1,89,125,89,0);
          		
                	drawingFrame = 1;
                	break;
  		end
  		case(1):
          		begin
          		video_box(14,16,110,84,1);//draw diploma
          		drawingFrame=2;
          		break;
          		end
    		case(2):
    			begin
          		
          		video_line(59,65,63,65,1);//top
          		video_line(59,80,63,80,1);//bottom
          		video_line(53,71,53,74,1);//left
          		video_line(69,71,69,74,1);//right
          		
          		video_pt(54,70,1);//NW
          		video_pt(54,69,1);
          		video_pt(55,68,1);
          		video_pt(56,67,1);
          		video_pt(57,66,1);
          		video_pt(58,66,1);  
          		
          		video_pt(68,70,1);//NE
          		video_pt(68,69,1);
          		video_pt(67,68,1);
          		video_pt(66,67,1);
          		video_pt(65,66,1);
          		video_pt(64,66,1);
          		
          		video_pt(54,75,1);//SW
          		video_pt(54,76,1);
          		video_pt(55,77,1);
          		video_pt(56,78,1);
          		video_pt(57,79,1);
          		video_pt(58,79,1);
          		
          		video_pt(68,75,1);//SE
          		video_pt(68,76,1);
          		video_pt(67,77,1);
          		video_pt(66,78,1);
          		video_pt(65,79,1);
          		video_pt(64,79,1); 
          		
          		video_line(57,74,57,70,1);//shield
          		video_line(57,69,65,69,1);
          		video_line(65,70,65,74,1);
          		video_pt(58,75,1);
          		video_pt(59,76,1);
          		video_pt(60,77,1);
          		video_pt(61,78,1);
          		video_pt(64,75,1);
          		video_pt(63,76,1);
          		video_pt(62,77,1);
          		
          		video_line(58,72,64,72,1);
          		video_box(59,73,63,75,1);
          		video_pt(61,70,1);
          		video_pt(61,71,1); 
          		drawingFrame = 3;
          		break;
  	    		end 
  	    case(3):
  	    		begin
				video_putsmalls(20,30,screenString);     
  	    			video_putsmalls(44,42,degreeString1);
  	    			video_putsmalls(40,50,degreeString2);
  	    			drawingFrame=4;
  	    		   	break;
  	    		end
  	    case(4):
  	    begin
  	    		sprintf(screenString,"CORNELL UNIVERSITY");
  	    		video_putsmalls(24,20,screenString);
  	    		break;
  	    end
  	end
end                             

//==================================
//prints out McDonald's arches used for finding a job without a degree
//==================================
void McDonalds(void)
begin
   	switch(drawingFrame)
   	begin
   		/*case(0):
   		begin
   			
   			video_line(26,60,34,60,1);   			
   			video_line(26,53,26,59,1);   			
   			video_line(27,45,27,52,1);   			
   			video_line(28,39,28,44,1); 
   			video_line(29,35,29,38,1);
    			video_line(30,31,30,34,1);
   			video_line(31,28,31,30,1);
   			video_line(32,25,32,27,1); 
   			video_line(33,22,33,24,1);
   	       		video_line(34,20,34,21,1);
   			video_line(34,52,34,59,1);
   			video_line(35,18,35,19,1);
   			video_line(35,45,35,51,1);
   			video_line(36,16,36,17,1);
   			video_line(36,37,36,44,1);
   			video_pt(37,15,1);   			
   			video_line(37,33,37,36,1);
   			video_pt(38,14,1);
   			video_line(38,28,38,32,1);
   			video_pt(39,13,1);
   			video_line(39,25,39,27,1);
   			video_pt(40,12,1);
   			video_line(40,22,40,24,1);
   			video_pt(41,12,1);
   			video_line(41,20,41,21,1);
   			video_pt(42,11,1);
               		video_line(42,17,42,19,1);
   			video_pt(43,11,1);
   			video_pt(43,16,1);
   			video_pt(44,11,1);
   			video_pt(44,16,1);
   			video_pt(45,11,1);
   			video_pt(45,17,1);
   			video_pt(46,11,1);
   			video_line(46,18,46,20,1);
   			video_pt(47,12,1);
   			video_line(47,21,47,24,1);
   			video_pt(48,13,1);
   			video_line(48,25,48,27,1);
   			video_pt(49,14,1);
   			video_line(49,28,49,33,1);
   			video_pt(50,15,1);
   			video_line(50,34,50,42,1);
   			video_line(51,16,51,17,1);
   			video_line(51,43,51,57,1);   			
   			video_line(52,18,52,19,1);  			
   			video_pt(52,57,1); 
   			video_line(53,20,53,22,1);   			
   			video_pt(53,23,1);
   			video_pt(53,57,1);
   			video_line(54,23,54,26,1);
   			video_pt(54,57,1);
   			video_pt(55,27,1);
   			video_pt(55,57,1); //end first half
   			
   			drawingFrame=1;  			
   			break;
   		end
   		case(1):
   		begin   			
   			video_line(85,60,77,60,1);
   			video_line(85,53,85,59,1);
   			video_line(84,45,84,52,1);
   			video_line(83,39,83,44,1);
   			video_line(82,35,82,38,1);
   			video_line(81,31,81,34,1);
   			video_line(80,28,80,30,1);
   			video_line(79,25,79,27,1);
   	       	video_line(78,22,78,24,1);
   			video_line(77,20,77,21,1);
   			video_line(77,52,77,59,1);
   			video_line(76,18,76,19,1);
   			video_line(76,45,76,51,1);
   			video_line(75,16,75,17,1);
   			video_line(75,37,75,44,1);
   			video_pt(74,15,1);
   			video_line(74,33,74,36,1);
   			video_pt(73,14,1);
   			video_line(73,28,73,32,1);
   			video_pt(72,13,1);
   			video_line(72,25,72,27,1);
   			video_pt(71,12,1);
   			video_line(71,22,71,24,1);
   			video_pt(70,12,1);
   			video_line(70,20,70,21,1);
   			video_pt(69,11,1);
   			video_line(69,17,69,19,1);
   			video_pt(68,11,1);
   			video_pt(68,16,1);
   			video_pt(67,11,1);
   			video_pt(67,16,1);
   			video_pt(66,11,1);
   			video_pt(66,17,1);
   			video_pt(65,11,1);
   			video_line(65,18,65,20,1);
   			video_pt(64,12,1);
   			video_line(64,21,64,24,1);
   			video_pt(63,13,1);
   			video_line(63,25,63,27,1);
   			video_pt(62,14,1);
   			video_line(62,28,62,33,1);
   			video_pt(61,15,1);
   			video_line(61,34,61,42,1);
   			video_line(60,16,60,17,1);
   			video_line(60,43,60,57,1);
   			video_line(59,18,58,19,1);
   			video_pt(59,57,1); 
   			video_line(58,20,58,22,1);
   			video_pt(58,23,1);
   			video_pt(58,57,1);
   			video_line(57,23,57,26,1);
   			video_pt(57,57,1);
   			video_pt(56,27,1);
   			video_pt(56,57,1); //beginning second half*/
			
			video_puts(25,40,screenString);
   			//break;
   		//end
   	end
end         
//==================================
// run the game
void main(void)
begin
   initialize();
	
  //The following loop executes once/video line during lines
  //1-230, then does all of the frame-end processing
  while(1)
  begin
    seed++;
    
    //stall here until next line starts
    //sleep enable; mode=idle  
    //use sleep to make entry into sync ISR uniform time  
     
    #asm ("sleep"); 
    
    //The following code executes during the vertical blanking
    //Code here can be as long as  
    //a total of 60 lines x 63.5 uSec/line x 8 cycles/uSec 
    
    if (LineCount==231)
    begin 
    	switch(songState)
    	//Play a note
        //TCCR0 bits:
        //bit 7 no force:
        //bit 3 CTC on: 
        //bit 5,4 toggle OC0 pin   
        //bit 6 no PWM
        //bit 2-0 prescaler 256 so 1 tick is 16 microsec

	       begin
	       	case(none): 
	       	begin
	       		songLength=0;
	       		songNoteLength=0;
	       		noteVal=0;
	       		noteReset=0;
	       		break;
	       	end
	       	case(alma):
	       	begin
	       		songLength=songAlma[0][0];
	       		songNoteLength=songAlma[1][noteIndex-1];
	       		noteVal=songAlma[0][noteIndex];
	       		noteReset=1;
          		break;
     	   	end
     	   	case(davy):
	       	begin
         			songLength=songDavy[0][0];
	       		songNoteLength=songDavy[1][noteIndex-1];
	       		noteVal=songDavy[0][noteIndex];
	       		noteReset=72; //song will only be played once, 72 is the last entry in the array which is a rest
          		break;
     	   	end  
     	   	case(bee):
	       	begin
				songLength=239;
	       		songNoteLength=6;
	       		noteVal=songBee[noteIndex];
	       		noteReset=1;
          	       break;
     	   	end
     	   	case(NCFS):
	       	begin
	        		songLength=songNCFS[0][0];
	       	     songNoteLength=songNCFS[1][noteIndex-1];
	       		noteVal=songNCFS[0][noteIndex];
	       		noteReset=1;
          	       break;
     	   	end
     	   	case(MYOC):
	       	begin
				songLength=songMYOC[0][0];
	       		songNoteLength=songMYOC[1][noteIndex-1];
	       		noteVal=songMYOC[0][noteIndex];
	       		noteReset=75;/ /song will only be played once, 75 is the last entry in the array which is a rest
          	       break;
     	   	end 
     	   	case(pomp):
	       	begin
         			songLength=songPomp[0][0];
	       		songNoteLength=2*songPomp[1][noteIndex-1];
	       		noteVal=songPomp[0][noteIndex];
	       		noteReset=19; //resets to chorus so it will play over and over 
          	       break;
     	   	end
     	   	case(McD):
	       	begin
         			songLength=songMcD[0][0];
	       		songNoteLength=2*songMcD[1][noteIndex-1];
	       		noteVal=songMcD[0][noteIndex];
	       		noteReset=9; //song will only play once
          	       break;
     	   	end
     	  end
     	  
     	  if((noteLength++) > songNoteLength)
          	       begin
          	       	noteLength = 0; 
          	       	TCCR0 = 0;
          	       	if (noteVal>0) TCCR0 = 0b00011100 ;  //not a rest
          	       	OCR0 = noteVal;
          	       	noteIndex++;    
          	       	count=count+2;
          	       	if (noteIndex>songLength) noteIndex=noteReset;        //test for end of song
          	       end
     	  
         	               	
         	readController(); 
         	if(pushFlag)
         	begin
         		switch(~controller)
         		begin
         			case(0x01): button = upButton; break;
         			case(0x02): button = downButton; break;
         			case(0x04): button = leftButton; break;
         			case(0x08): button = rightButton; break;
         			case(0x10): button = BButton; break;
         			case(0x20): button = CButton; break;
         			case(0x40): button = AButton; break;
         			case(0x80): button = startButton; break;
         			case(0x06): button = downLeftButton; break;
         			case(0x09): button = upRightButton; break;
         			default: button=0; break;
         		end
         		//bits will be associated with: (7 to 0)
        		//Start, Button A, Button C, Button B, Right, Left, Down, Up
         		pushFlag=0;
         	end
         	
         	switch(yearState)
         	begin
         		case(prefrosh):
         		begin
         			enroll(); //clears start screen and initializes for wordscramble
         			break;
         		end
         		case(frosh):
         		begin  
         			wordScrambleStateMachine();
         			break;
         		end
         		case(soph):
         		begin  
         			ThumbelinaStateMachine();
         			break;
         		end
         		case(junior):
         		begin  
         			DDRStateMachine();
         			break;
         		end 
         		case(senior):
         		begin
         			break;
         		end
         		case(trans):
         		begin
         			if (credits > 99) //more than 100 credits means you win! and get to graduate
         			begin
         				sprintf(screenString,"COLLEGE OF ENGINEERING");
         				yearState=grad;
         				songState = pomp;
         			end
         			else	transfer();
         			break;
         		end	 
         		case(grad):
         		begin
         			graduate();
         			break;
         		end
         		case(job):
         		begin      
         			McDonalds();
         		   	break;
         		end
         		
         		
         		default: break;
         	end
         			

              
     end  //line 231
  end  //while
end  //main